@@ -1,12 +1,13 @@
-/*  $Revision: 1.5 $
+/*  $Revision: 1.10.4.3 $
 **
 **  Read batchfiles on standard input and archive them.
 */
-#include "configdata.h"
 #include <stdio.h>
+#include <sys/types.h>
+#include "configdata.h"
+#include "clibrary.h"
 #include <ctype.h>
 #include <errno.h>
-#include <sys/types.h>
 #include <sys/stat.h>
 #if	defined(DO_NEED_TIME)
 #include <time.h>
@@ -15,14 +16,12 @@
 #include "paths.h"
 #include "libinn.h"
 #include "qio.h"
-#include "clibrary.h"
 #include "macros.h"
+#include <syslog.h> 
 
 
-STATIC STRING	Archive = _PATH_ARCHIVEDIR;
-STATIC char	SPOOL[] = _PATH_SPOOL;
-static char	BATCHDIR[] = _PATH_BATCHDIR;
-
+STATIC char	*Archive = NULL;
+STATIC char	*ERRLOG = NULL;
 
 /*
 **  Try to make one directory.  Return FALSE on error.
@@ -45,7 +44,7 @@ MakeDir(Name)
 **  Given an entry, comp/foo/bar/1123, create the directory and all
 **  parent directories needed.  Return FALSE on error.
 */
-BOOL
+STATIC BOOL
 MakeArchiveDirectory(Name)
     register char	*Name;
 {
@@ -65,7 +64,7 @@ MakeArchiveDirectory(Name)
 
     /* Try to make each of comp and comp/foo in turn. */
     for (p = Name; *p; p++)
-	if (*p == '/') {
+	if (*p == '/' && p != Name) {
 	    *p = '\0';
 	    made = MakeDir(Name);
 	    *p = '/';
@@ -99,7 +98,7 @@ WriteIndex(FullName, ShortName)
     char		MessageID[BUFSIZ];
 
     /* Open the file. */
-    if ((qp = QIOopen(FullName, QIO_BUFFER)) == NULL) {
+    if ((qp = QIOopen(FullName)) == NULL) {
 	(void)printf("%s <open error> %s\n", ShortName, strerror(errno));
 	return;
     }
@@ -117,6 +116,9 @@ WriteIndex(FullName, ShortName)
 		(void)QIOread(qp);
 		continue;
 	    }
+
+	    /* End of headers (and article) -- we're done. */
+	    break;
 	}
 
 	/* End of headers -- we're done. */
@@ -229,6 +231,85 @@ Copy(src, dest)
 }
 
 
+/*
+**  Copy an article from memory into a file.
+*/
+STATIC BOOL
+CopyArt(ARTHANDLE *art, char *dest)
+{
+    register FILE	*out;
+    char		*p,*q,*last;
+    ARTHANDLE		article;
+    size_t		i;
+
+    /* Open the output file. */
+    if ((out = fopen(dest, "w")) == NULL) {
+	/* Failed; make any missing directories and try again. */
+	if ((p = strrchr(dest, '/')) != NULL) {
+	    if (!MakeArchiveDirectory(dest)) {
+		(void)fprintf(stderr, "Can't mkdir for \"%s\", %s\n",
+			dest, strerror(errno));
+		return FALSE;
+	    }
+	    out = fopen(dest, "w");
+	}
+	if (p == NULL || out == NULL) {
+	    (void)fprintf(stderr, "Can't open \"%s\" for writing, %s\n",
+		    dest, strerror(errno));
+	    return FALSE;
+	}
+    }
+
+    /* Copy the data. */
+    article.data = NEW(char, art->len);
+    for (i=0, last=NULL, q=article.data, p=art->data; p<art->data+art->len;) {
+	if (&p[1] < art->data + art->len && p[0] == '\r' && p[1] == '\n') {
+	    p += 2;
+	    *q++ = '\n';
+	    i++;
+	    if (&p[1] < art->data + art->len && p[0] == '.' && p[1] == '.') {
+		p += 2;
+		*q++ = '.';
+		i++;
+	    }
+	    if (&p[2] < art->data + art->len && p[0] == '.' && p[1] == '\r' && p[2] == '\n') {
+		break;
+	    }
+	} else {
+	    *q++ = *p++;
+	    i++;
+	}
+    }
+    *q++ = '\0';
+
+    /* Write the data. */
+    if (fwrite(article.data, i, 1, out) != 1) {
+	(void)fprintf(stderr, "Can't write \"%s\", %s\n",
+		dest, strerror(errno));
+	(void)fclose(out);
+	(void)unlink(dest);
+	return FALSE;
+    }
+
+    /* Flush and close the output. */
+    if (ferror(out) || fflush(out) == EOF) {
+	(void)fprintf(stderr, "Can't close \"%s\", %s\n",
+		dest, strerror(errno));
+	(void)unlink(dest);
+	(void)fclose(out);
+	return FALSE;
+    }
+    if (fclose(out) == EOF) {
+	(void)fprintf(stderr, "Can't close \"%s\", %s\n",
+		dest, strerror(errno));
+	(void)unlink(dest);
+	return FALSE;
+    }
+
+    return TRUE;
+}
+
+
 /*
 **  Print a usage message and exit.
 */
@@ -257,13 +338,23 @@ main(ac, av)
     char		buff[BUFSIZ];
     char		temp[BUFSIZ];
     char		dest[BUFSIZ];
+    char		*groups, *q;
+    ARTHANDLE		*art;
+    TOKEN		token;
     struct stat		Sb;
 
+    /* First thing, set up logging and our identity. */
+    openlog("archive", L_OPENLOG_FLAGS | LOG_PID, LOG_INN_PROG);
+
     /* Set defaults. */
+    if (ReadInnConf() < 0) exit(1);
     Flat = FALSE;
     Index = NULL;
     Move = FALSE;
     Redirect = TRUE;
+    (void)umask(NEWSUMASK);
+    ERRLOG = COPY(cpcatpath(innconf->pathlog, _PATH_ERRLOG));
+    Archive = innconf->patharchive;
 
     /* Parse JCL. */
     while ((i = getopt(ac, av, "a:fi:mr")) != EOF)
@@ -287,10 +378,10 @@ main(ac, av)
 	    Redirect = FALSE;
 	    break;
 	}
-#if	defined(DONT_HAVE_SYMLINK)
+#if !defined(HAVE_SYMLINK)
 	if (Move)
 	    (void)fprintf(stderr, "archive:  Ignoring ``-m'' flag\n");
-#endif	/* defined(DONT_HAVE_SYMLINK) */
+#endif	/* !defined(HAVE_SYMLINK) */
 
     /* Parse arguments -- at most one, the batchfile. */
     ac -= optind;
@@ -300,7 +391,7 @@ main(ac, av)
 
     /* Do file redirections. */
     if (Redirect)
-	(void)freopen(_PATH_ERRLOG, "a", stderr);
+	(void)freopen(ERRLOG, "a", stderr);
     if (ac == 1 && freopen(av[0], "r", stdin) == NULL) {
 	(void)fprintf(stderr, "archive:  Can't open \"%s\" for input, %s\n",
 		av[0], strerror(errno));
@@ -313,9 +404,9 @@ main(ac, av)
     }
 
     /* Go to where the action is. */
-    if (chdir(SPOOL) < 0) {
+    if (chdir(innconf->patharticles) < 0) {
 	(void)fprintf(stderr, "archive:  Can't cd to \"%s\", %s\n",
-		SPOOL, strerror(errno));
+		innconf->patharticles, strerror(errno));
 	exit(1);
     }
 
@@ -324,6 +415,14 @@ main(ac, av)
     Name = dest + strlen(dest);
     *Name++ = '/';
 
+    /* If storageapi is being used, initialize... */
+    if (innconf->storageapi) {
+	if (!SMinit()) {
+	    (void)fprintf(stderr, "archive: Could not initialize the storage manager: %s", SMerrorstr);
+	    exit(1);
+	}
+    }
+
     /* Read input. */
     while (fgets(buff, sizeof buff, stdin) != NULL) {
 	if ((p = strchr(buff, '\n')) == NULL) {
@@ -336,66 +435,133 @@ main(ac, av)
 	if (buff[0] == '\0' || buff[0] == COMMENT_CHAR)
 	    continue;
 
-	/* Make sure we're only copying files. */
-	if (stat(buff, &Sb) < 0) {
-	    if (errno != ENOENT)
-		(void)fprintf(stderr, "Can't stat \"%s\", %s\n",
-			buff, strerror(errno));
-	    continue;
-	}
-	if (!S_ISREG(Sb.st_mode)) {
-	    (void)fprintf(stderr, "\"%s\" is not a regular file\n", buff);
-	    continue;
-	}
-
-	/* Set up the destination name. */
-	(void)strcpy(Name, buff);
-	if (Flat) {
-	    for (last = NULL, p = Name; *p; p++)
-		if (*p == '/') {
-		    last = p;
-		    *p = '.';
-		}
-	    if (last)
-		*last = '/';
-	}
-
-#if	defined(DO_HAVE_SYMLINK)
-	if (Move) {
-	    if (!Copy(buff, dest))
-		continue;
-	    if (unlink(buff) < 0 && errno != ENOENT)
-		(void)fprintf(stderr, "Can't remove \"%s\", %s\n",
-			buff, strerror(errno));
-	    if (symlink(dest, buff) < 0)
-		(void)fprintf(stderr, "Can't symlink \"%s\" to \"%s\", %s\n",
-			buff, dest, strerror(errno));
-	    continue;
-	}
-#endif	/* defined(DO_HAVE_SYMLINK) */
-
-	/* Try to link the file into the archive. */
-	if (link(buff, dest) < 0) {
-
-	    /* Make the archive directory. */
-	    if (!MakeArchiveDirectory(dest)) {
-		(void)fprintf(stderr, "Can't mkdir for \"%s\", %s\n",
-			dest, strerror(errno));
+	/* Check to see if this is a token... */
+	if (IsToken(buff)) {
+	    /* Get a copy of the article. */
+	    token = TextToToken(buff);
+	    if ((art = SMretrieve(token, RETR_ALL)) == NULL) {
+		(void)fprintf(stderr, "Could not retrieve %s\n",
+			buff);
 		continue;
 	    }
 
-	    /* Try to link again; if that fails, make a copy. */
-	    if (link(buff, dest) < 0 && !Copy(buff, dest))
-		continue;
-	}
+	    /* Determine groups from the Xref header */
+    	    groups = (char *)HeaderFindMem(art->data, art->len, "Xref", 4);
 
-	/* Write index. */
-	if (Index) {
-	    WriteIndex(dest, Name);
-	    if (ferror(stdout))
-		(void)fprintf(stderr, "Can't write index for \"%s\", %s\n",
-			Name, strerror(errno));
+	    /* Skip over the newsserver name */
+	    while (*groups!=' ' && *groups!='\r' && *groups!='\n') {
+		groups++;
+	    }
+	    while (*groups==' ') {
+		groups++;
+	    }
+
+	    /* Process newsgroup... */
+	    if (*groups!='\r' && *groups!='\n' && *groups!='\0') {
+		p = Name;
+		while(*groups!=' ' && *groups!='\r' && *groups!='\n') {
+		    *p++ = *groups++; 
+		}
+		*p='\0';
+		if ((p=strchr(Name, ':')) == NULL) {
+		    fprintf(stderr, "archive: bogus xref '%s'\n", Name);
+		    SMfreearticle(art);
+		    continue;
+		}
+		*p='/';
+
+		if (!Flat) {
+		    for (p=Name; *p; p++) {
+			if (*p == '.') {
+			    *p = '/';
+			}
+		    }
+		}
+
+		if (!CopyArt(art, dest)) {
+		    fprintf(stderr, 
+			"archive: %s->%s failed\n", buff, dest);
+		}
+
+	        /* Write index. */
+	        if (Index) {
+	            WriteIndex(dest, Name);
+	            if (ferror(stdout) || fflush(stdout) == EOF)
+		        (void)fprintf(stderr, "Can't write index for \"%s\", %s\n",
+			        Name, strerror(errno));
+	        }
+	    }
+
+	    /* Free up the article storage space */
+	    SMfreearticle(art);
 	}
+	else {
+	    /* Make sure we're only copying files. */
+	    if (stat(buff, &Sb) < 0) {
+	        if (errno != ENOENT)
+		    (void)fprintf(stderr, "Can't stat \"%s\", %s\n",
+			    buff, strerror(errno));
+	        continue;
+	    }
+	    if (!S_ISREG(Sb.st_mode)) {
+	        (void)fprintf(stderr, "\"%s\" is not a regular file\n", buff);
+	        continue;
+	    }
+
+	    /* Set up the destination name. */
+	    (void)strcpy(Name, buff);
+	    if (Flat) {
+	        for (last = NULL, p = Name; *p; p++)
+		    if (*p == '/') {
+		        last = p;
+		        *p = '.';
+		    }
+	        if (last)
+		    *last = '/';
+	    }
+
+#if	defined(HAVE_SYMLINK)
+	    if (Move) {
+	        if (!Copy(buff, dest))
+		    continue;
+	        if (unlink(buff) < 0 && errno != ENOENT)
+		    (void)fprintf(stderr, "Can't remove \"%s\", %s\n",
+			    buff, strerror(errno));
+	        if (symlink(dest, buff) < 0)
+		    (void)fprintf(stderr, "Can't symlink \"%s\" to \"%s\", %s\n",
+			    buff, dest, strerror(errno));
+	        continue;
+	    }
+#endif	/* defined(HAVE_SYMLINK) */
+
+	    /* Try to link the file into the archive. */
+	    if (link(buff, dest) < 0) {
+
+	        /* Make the archive directory. */
+	        if (!MakeArchiveDirectory(dest)) {
+		    (void)fprintf(stderr, "Can't mkdir for \"%s\", %s\n",
+			    dest, strerror(errno));
+		    continue;
+	        }
+
+	        /* Try to link again; if that fails, make a copy. */
+	        if (link(buff, dest) < 0 && !Copy(buff, dest))
+		    continue;
+	    }
+
+	    /* Write index. */
+	    if (Index) {
+	        WriteIndex(dest, Name);
+	        if (ferror(stdout) || fflush(stdout) == EOF)
+		    (void)fprintf(stderr, "Can't write index for \"%s\", %s\n",
+			    Name, strerror(errno));
+	    }
+	}
+    }
+
+    /* close down the storage manager api */
+    if (innconf->storageapi) {
+	SMshutdown();
     }
 
     /* If we read all our input, try to remove the file, and we're done. */
@@ -409,11 +575,11 @@ main(ac, av)
     /* Make an appropriate spool file. */
     p = av[0];
     if (p == NULL)
-	(void)sprintf(temp, "%s/%s", BATCHDIR, "archive");
+	(void)sprintf(temp, "%s/%s", innconf->pathoutgoing, "archive");
     else if (*p == '/')
 	(void)sprintf(temp, "%s.bch", p);
     else
-	(void)sprintf(temp, "%s/%s.bch", BATCHDIR, p);
+	(void)sprintf(temp, "%s/%s.bch", innconf->pathoutgoing, p);
     if ((F = xfopena(temp)) == NULL) {
 	(void)fprintf(stderr, "archive: Can't spool to \"%s\", %s\n",
 	    temp, strerror(errno));
