@@ -1,4 +1,4 @@
-/*  $Revision: 1.18 $
+/*  $Revision: 1.20.2.1 $
 **
 **  Transmit articles to remote site.
 **  Modified for NNTP streaming: 3Jan96 Jerry Aguirre
@@ -271,7 +271,7 @@ stidhash(MessageID)
     hash = 0;
     for (p = MessageID + 1; *p && (*p != '>'); p++) {
 	hash <<= 1;
-	if (isascii(*p) && isupper(*p)) {
+	if (isascii((int)*p) && isupper((int)*p)) {
 	    hash += tolower(*p);
 	} else {
 	    hash += *p;
@@ -869,11 +869,12 @@ GetMessageID(qp)
 	    if (*p == '\0')
 		/* Header is empty*/
 		break;
-	    if (strlen(p) >= buffsize) {
+	    if (strlen(p) > buffsize) {
 		if (buffsize)
-		    buff = RENEW(buff, char, strlen(p) + 1);
+		    RENEW(buff, char, strlen(p) + 1);
 		else
 		    buff = NEW(char, strlen(p) + 1);
+		buffsize = strlen(p);
 		
 	    }
 	    (void)strcpy(buff, p);
@@ -1544,13 +1545,14 @@ int main(int ac, char *av[])
 		continue;
 	    }
 	    if (ContentEncoding 
-	     && (caseEQ(ContentEncoding, "binary")
-	      || caseEQ(ContentEncoding, "8bit")))
+		&& (caseEQ(ContentEncoding, "binary")
+		 || caseEQ(ContentEncoding, "8bit"))) {
 		if (ContentType == NULL || caseEQ(ContentType, "text"))
 		    MimeArticle = MTquotedprintable;
-		else
+		} else {
 		    /* Shouldbe MTbase64, but not implemented yet. */
 		    MimeArticle = MTnotmime;
+		}
 	}
 	if (GotInterrupt)
 	    Interrupted(Article, MessageID);
@@ -1697,4 +1699,5 @@ int main(int ac, char *av[])
 		BATCHtemp, strerror(errno));
     ExitWithStats(0);
     /* NOTREACHED */
+    return 0;
 }
