@@ -1,17 +1,18 @@
-/*  $Revision: 1.7 $
+/*  $Revision: 1.9 $
 **
 **  Prune file names from history file.
 */
-#include "configdata.h"
 #include <stdio.h>
-#include <errno.h>
 #include <sys/types.h>
+#include "configdata.h"
+#include "clibrary.h"
+#include <errno.h>
 #include <fcntl.h>
 #include "paths.h"
 #include "libinn.h"
-#include "clibrary.h"
 #include "dbz.h"
 #include "macros.h"
+#include <syslog.h>  
 
 
 /*
@@ -32,7 +33,6 @@ Splice(name, Line)
     register char	*name;
     BUFFER		*Line;
 {
-    static char		SPOOL[] = _PATH_SPOOL;
     register char	*last;
     register char	*p;
     register char	*end;
@@ -41,9 +41,9 @@ Splice(name, Line)
 
     /* Make sure it's a relative pathname. */
     if (name[0] == '/'
-     && name[STRLEN(SPOOL)] == '/'
-     && EQn(name, SPOOL, STRLEN(SPOOL)))
-	name += STRLEN(SPOOL);
+     && name[strlen(innconf->patharticles)] == '/'
+     && EQn(name, innconf->patharticles, strlen(innconf->patharticles)))
+	name += strlen(innconf->patharticles);
 
     /* Turn foo/bar/baz into foo.bar/baz and get the length. */
     for (last = NULL, p = name; *p; p++)
@@ -87,7 +87,6 @@ main(ac, av)
 {
     static char		SEPS[] = " \t";
     register char	*p;
-    register char	*q;
     register FILE	*rfp;
     register int	wfd;
     register int	c;
@@ -95,14 +94,22 @@ main(ac, av)
     OFFSET_T		where;
     char		buff[BUFSIZ];
     char		*files;
-    datum		key;
-    datum		value;
+    HASH		key;
     STRING		History;
     BUFFER		Line;
     BOOL		Passing;
+#ifndef DO_TAGGED_HASH
+    idxrec		ionevalue;
+    idxrecext		iextvalue;
+#endif
+
+    /* First thing, set up logging and our identity. */
+    openlog("prunehistory", L_OPENLOG_FLAGS | LOG_PID, LOG_INN_PROG);      
 
     /* Set defaults. */
-    History = _PATH_HISTORY;
+    if (ReadInnConf() < 0) exit(1);
+
+    History = cpcatpath(innconf->pathdb, _PATH_HISTORY);
     Line.Size = BUFSIZ;
     Line.Data = NEW(char, Line.Size);
     Line.Used = 0;
@@ -127,7 +134,7 @@ main(ac, av)
 	Usage();
 
     /* Open files. */
-    if (dbminit(History) < 0) {
+    if (!dbzinit(History)) {
 	(void)fprintf(stderr, "Can't set up \"%s\" database, %s\n",
 		History, strerror(errno));
 	exit(1);
@@ -174,19 +181,32 @@ main(ac, av)
 	*++p = '\0';
 	files = p + 1;
 
-	/* Loop up the article. */
-	key.dsize = p - buff + 1;
-	key.dptr = buff;
-	value = dbzfetch(key);
-	if (value.dptr == NULL || value.dsize != sizeof where) {
+	/* Look up the article. */
+	key = HashMessageID(buff);
+#ifdef	DO_TAGGED_HASH
+	if ((where = dbzfetch(key)) < 0) {
 	    (void)fprintf(stderr, "No entry for \"%s\", %s\n",
 		    buff, strerror(errno));
 	    continue;
 	}
+#else
+	if (innconf->extendeddbz) {
+	    if (!dbzfetch(key, &iextvalue)) {
+		(void)fprintf(stderr, "No entry for \"%s\", %s\n",
+		    buff, strerror(errno));
+		continue;
+	    }
+	    where = iextvalue.offset[HISTOFFSET];
+	} else {
+	    if (!dbzfetch(key, &ionevalue)) {
+		(void)fprintf(stderr, "No entry for \"%s\", %s\n",
+		    buff, strerror(errno));
+		continue;
+	    }
+	    where = ionevalue.offset;
+	}
+#endif
 
-	/* Copy the value to an aligned spot. */
-	for (p = value.dptr, q = (char *)&where, i = sizeof where; --i >= 0; )
-	    *q++ = *p++;
 	if (fseek(rfp,  where, SEEK_SET) == -1) {
 	    (void)fprintf(stderr, "Can't fseek for \"%s\", %s\n",
 		    buff, strerror(errno));
