@@ -2,7 +2,7 @@
     These are the definitions used for inn.conf variables and used
     primarily in lib/getconfig.c
 
-    $Header: /proj/cvs/isc/inn/inn/include/innconf.h,v 1.9 1998/06/26 00:44:16 kondou Exp $
+    $Header: /proj/cvs/isc/inn/inn/include/innconf.h,v 1.14.2.2 1998/11/07 03:00:24 kondou Exp $
 */
 
 /*
@@ -123,9 +123,9 @@ struct conf_rec conf_defaults[] = {
 #define _CONF_CLIENTTIMEOUT			"clienttimeout"
 #define CONF_VAR_CLIENTTIMEOUT			33
     { _CONF_CLIENTTIMEOUT,			"",	2, 1 },
-#define _CONF_ALLOWREADERS			"allowreaders"
-#define CONF_VAR_ALLOWREADERS			34
-    { _CONF_ALLOWREADERS,			"",	2, 1 },
+#define _CONF_READERSWHENSTOPPED		"readerswhenstopped"
+#define CONF_VAR_READERSWHENSTOPPED		34
+    { _CONF_READERSWHENSTOPPED,			"",	2, 1 },
 #define _CONF_ALLOWNEWNEWS			"allownewnews"
 #define CONF_VAR_ALLOWNEWNEWS			35
     { _CONF_ALLOWNEWNEWS,			"",	2, 1 },
@@ -300,6 +300,27 @@ struct conf_rec conf_defaults[] = {
 #define _CONF_STOREMSGID			"storemsgid"
 #define CONF_VAR_STOREMSGID			92
     { _CONF_STOREMSGID,				"",	2, 1 },
+#define _CONF_NICENEWNEWS			"nicenewnews"
+#define CONF_VAR_NICENEWNEWS			93
+    { _CONF_NICENEWNEWS,			"",	2, 1 },
+#define _CONF_USECONTROLCHAN			"usecontrolchan"
+#define CONF_VAR_USECONTROLCHAN			94
+    { _CONF_USECONTROLCHAN,			"",	2, 1 },
+#define _CONF_MERGETOGROUPS			"mergetogroups"
+#define CONF_VAR_MERGETOGROUPS			95
+    { _CONF_MERGETOGROUPS,			"",	2, 1 },
+#define _CONF_NOREADER				"noreader"
+#define CONF_VAR_NOREADER			96
+    { _CONF_NOREADER,				"",	2, 1 },
+#define _CONF_SOURCEADDRESS			"sourceaddress"
+#define CONF_VAR_SOURCEADDRESS			97
+    { _CONF_SOURCEADDRESS,			"",	1, 1 },
+#define _CONF_NNRPPERLAUTH			"nnrpperlauth"
+#define CONF_VAR_NNRPPERLAUTH			98
+    { _CONF_NNRPPERLAUTH,			"",	2, 1 },
+#define _CONF_NNRPDPOSTPORT			"nnrpdpostport"
+#define CONF_VAR_NNRPDPOSTPORT			99
+    { _CONF_NNRPDPOSTPORT,			"",	2, 1 }
 };
-#define MAX_CONF_VAR 93
+#define MAX_CONF_VAR 100
 
