@@ -1,4 +1,4 @@
-/*  $Id: icd.c,v 1.10 1998/05/20 10:08:09 scrappy Exp $
+/*  $Id: icd.c,v 1.13 1998/10/21 07:28:06 brister Exp $
 **
 **  Routines to read and write the active file.
 */
@@ -83,12 +83,14 @@ ICDsetup(StartSites)
 	syslog(L_FATAL, "%s internal no control and/or junk group", LogName);
 	exit(1);
     }
-#if	defined(DO_MERGE_TO_GROUPS)
-    if (NGfind("to") == NULL) {
+    if (innconf->usecontrolchan && NGfind("control.cancel") == NULL) {
+	syslog(L_FATAL, "%s internal no control.cancel group", LogName);
+	exit(1);
+    }
+    if (innconf->mergetogroups && NGfind("to") == NULL) {
 	syslog(L_FATAL, "%s internal no to group", LogName);
 	exit(1);
     }
-#endif	/* defined(DO_MERGE_TO_GROUPS) */
     SITEparsefile(StartSites);
 }
 
@@ -394,7 +396,7 @@ ICDwriteactive()
         exit(1);
     }
 #else
-    if (msync(ICDactpointer, 0) < 0) {
+    if (msync(ICDactpointer, ICDactsize) < 0) {
         syslog(L_FATAL, "%s msync failed %s %m", LogName, ICDactpath);
         exit(1);
     }
