@@ -1,4 +1,4 @@
-/*  $Id: innd.c,v 1.40 1998/09/05 15:04:28 kondou Exp $
+/*  $Id: innd.c,v 1.40.2.3 1999/07/08 21:18:34 kondou Exp $
 **
 **  Variable definitions, miscellany, and main().
 */
@@ -75,7 +75,7 @@ STATIC GID_T	NewsGID;
 BOOL
 FormatLong(p, value, width)
     register char	*p;
-    register long	value;
+    register u_long	value;
     register int	width;
 {
     for (p += width - 1; width-- > 0; ) {
@@ -639,8 +639,8 @@ int main(int ac, char *av[])
 	    default:
 		Usage();
 		/* NOTREACHED */
-	    case 'n':	innconf->readerswhenstopped = TRUE;	break;
-	    case 'y':	innconf->readerswhenstopped = FALSE;	break;
+	    case 'n':	innconf->readerswhenstopped = FALSE;	break;
+	    case 'y':	innconf->readerswhenstopped = TRUE;	break;
 	    }
 	    break;
 	case 'o':
@@ -709,17 +709,17 @@ int main(int ac, char *av[])
 
     val = FALSE;
     if (!OVERsetup(OVER_MMAP, &val)) {
-	syslog(L_FATAL, "%s cant setup for the unified overview no mmap");
+	syslog(L_FATAL, "%s cant setup for the unified overview no mmap", LogName);
 	exit(1);
     }
     val = TRUE;
     if (!OVERsetup(OVER_PREOPEN, &val)) {
-	syslog(L_FATAL, "%s cant setup for the unified overview preopen");
+	syslog(L_FATAL, "%s cant setup for the unified overview preopen", LogName);
 	exit(1);
     }
 
     if (innconf->storageapi && (Overfdcount = OVERgetnum()) < 0) {
-	syslog(L_FATAL, "%s cant get config for the unified overview");
+	syslog(L_FATAL, "%s cant get config for the unified overview", LogName);
 	exit(1);
     }
 
