@@ -1,4 +1,4 @@
-/*  $Id: nc.c,v 1.37.2.7 1999/10/04 02:43:50 kondou Exp $
+/*  $Id: nc.c,v 1.37.2.9 2000/01/17 13:31:24 kondou Exp $
 **
 **  Routines for the NNTP channel.  Other channels get the descriptors which
 **  we turn into NNTP channels, and over which we speak NNTP.
@@ -782,7 +782,7 @@ STATIC FUNCTYPE NCproc(CHANNEL *cp)
 		int j;
 		char *tmpstr;
 
-		tmpstr = NEW(char, bp->Used);
+		tmpstr = NEW(char, bp->Used + 1);
 		memcpy(tmpstr, bp->Data, bp->Used);
 		tmpstr[bp->Used] = '\0';
 		
@@ -1246,11 +1246,11 @@ NCcreate(int fd, BOOL MustAuthorize, BOOL IsLocal)
     NCcount++;
     if (Mode == OMthrottled) {
 	NCwriteshutdown(cp, ModeReason);
-	return cp;
+	return NULL;
     }
     if (RejectReason) {
 	NCwriteshutdown(cp, RejectReason);
-	return cp;
+	return NULL;
     }
 
     /* See if we have too many channels. */
