@@ -1,4 +1,4 @@
-/*  $Id: site.c,v 1.20 1998/06/01 00:30:00 kondou Exp $
+/*  $Id: site.c,v 1.22.2.1 1999/04/19 06:54:46 kondou Exp $
 **
 **  Routines to implement site-feeding.  Mainly working with channels to
 **  do buffering and determine what to send.
@@ -63,8 +63,8 @@ BOOL SITEspool(SITE *sp, CHANNEL *cp)
 	xchown(name);
     if (cp) {
       if (cp->fd >= 0)
-        syslog(L_ERROR, "DEBUG ERROR SITEspool trashed:%d %s:%d", cp->fd, sp->Name, i);
-	/* CPU-eating bug, killed by kre. */
+        /* syslog(L_ERROR, "DEBUG ERROR SITEspool trashed:%d %s:%d", cp->fd, sp->Name, i);
+	   CPU-eating bug, killed by kre. */
 	WCHANremove(cp);
 	RCHANremove(cp);
 	SCHANremove(cp);
@@ -514,7 +514,10 @@ void SITEsend(SITE *sp, ARTDATA *Data)
 	}
 
 	/* Feed the article on standard input. */
-	fd = open(Data->Name, O_RDONLY);
+	if (IsToken(Data->Name))
+	    fd = 0;
+	else
+	    fd = open(Data->Name, O_RDONLY);
 	if (fd < 0) {
 	    /* Unlikely, but we could check if the article is cross-posted
 	     * and try it under other names... */
@@ -568,11 +571,19 @@ STATIC BOOL SITEstartprocess(SITE *sp)
     int			*ip;
     int			pan[2];
 
+#if HAVE_SOCKETPAIR
+    /* Create a socketpair. */
+    if (socketpair(PF_UNIX, SOCK_STREAM, 0, pan) < 0) {
+	syslog(L_ERROR, "%s cant socketpair %m", sp->Name);
+	return FALSE;
+    }
+#else
     /* Create a pipe. */
     if (pipe(pan) < 0) {
 	syslog(L_ERROR, "%s cant pipe %m", sp->Name);
 	return FALSE;
     }
+#endif
     CloseOnExec(pan[PIPE_WRITE], TRUE);
 
     /* Set up the argument vector. */
