@@ -1,5 +1,5 @@
 
-/* $Id: status.c,v 1.12.2.1 1999/06/20 21:56:36 kondou Exp $ */
+/* $Id: status.c,v 1.12.2.3 1999/10/04 02:20:59 kondou Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -34,7 +34,7 @@ typedef struct _STATUS {
     unsigned long  Unwanted_g;
     unsigned long  Unwanted_s;
     unsigned long  Unwanted_f;
-    unsigned long  Size;
+    float          Size;
     unsigned long  Check;
     unsigned long  Check_send;
     unsigned long  Check_deferred;
@@ -77,7 +77,7 @@ void STATUSinit(void)
   strcpy (start_time, ctime (&now)) ;
 }
 
-char *PrettySize (unsigned long size, char *str)
+char *PrettySize (float size, char *str)
 {
   if (size > 1073741824) /* 1024*1024*1024 */
     sprintf (str, "%.1fGb", size / 1073741824.);
@@ -102,7 +102,7 @@ static void STATUSsummary(void)
   unsigned long     accepted = 0;
   unsigned long     refused = 0;
   unsigned long     rejected = 0;
-  unsigned long     size = 0;
+  float             size = 0;
   int               peers = 0;
   char              TempString [SMBUF];
   STATUS            status[MAX_PEER];
@@ -137,7 +137,7 @@ static void STATUSsummary(void)
     strcpy(TempString, cp->Address.s_addr == 0 ? "localhost" : RChostname(cp));
     while ((j < peers) && (strcmp (TempString, status[j].name)))
       j++;
-    if (j > MAX_PEER) {
+    if (j >= MAX_PEER) {
       syslog(L_NOTICE, "%s: too many peers for STATUSsummary()", TempString);
       fprintf (F, "%s: too many peers for STATUSsummary()\n", TempString);
       continue;
