@@ -4,7 +4,7 @@
  * Start Date:  Thu Dec 28 13:15:04 1995
  * Project:     INN (innfeed)
  * File:        innlistener.c
- * RCSId:       $Id: innlistener.c,v 1.10 1998/07/06 07:23:42 kondou Exp $
+ * RCSId:       $Id: innlistener.c,v 1.11.2.1 1999/03/07 14:56:57 kondou Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -29,7 +29,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: innlistener.c,v 1.10 1998/07/06 07:23:42 kondou Exp $" ;
+static const char *rcsid = "$Id: innlistener.c,v 1.11.2.1 1999/03/07 14:56:57 kondou Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -464,9 +464,20 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
 
           return ;
         }
-      expandBuffer (buffs [0], BUFFER_EXPAND_AMOUNT) ;
+      if (blen == bufferSize(buffs [0])) {
+        if (!expandBuffer (buffs [0], BUFFER_EXPAND_AMOUNT)) {
+          syslog (LOG_CRIT,L_BUFFER_EXPAND_ERROR);
+          shutDown (lis) ;
+          return ;
+        }
+      }
       readArray = makeBufferArray (bufferTakeRef (buffs [0]),NULL) ;
-      prepareRead (ep, readArray, newArticleCommand, data, 1) ;
+      if (!prepareRead (ep, readArray, newArticleCommand, data, 1)) {
+        syslog (LOG_CRIT,L_PREPARE_READ_FAILED) ;
+        freeBufferArray (readArray) ;
+        shutDown (lis) ;
+        return ;
+      }
     }
   else
     {
@@ -578,20 +589,10 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
           Buffer *bArr ;
           u_int leftAmt = blen - (cmd - bbase) ;
 
+          ASSERT (cmd != bbase) ;
           /* first we shift whats left in the buffer down to the bottom */
-          if (cmd != bbase)
-            {
-              memmove (bbase,cmd,leftAmt) ;
-              bufferSetDataSize (buffs [0],leftAmt) ;
-            }
-          else if ( !expandBuffer (buffs[0],BUFFER_EXPAND_AMOUNT) )
-            {
-              syslog (LOG_CRIT,L_BUFFER_EXPAND_ERROR);
-
-              shutDown (lis) ;
-
-              return ;
-            }
+          memmove (bbase,cmd,leftAmt) ;
+          bufferSetDataSize (buffs [0],leftAmt) ;
       
           bArr = makeBufferArray (bufferTakeRef (buffs [0]),NULL) ;
       
@@ -684,7 +685,10 @@ static void giveArticleToPeer (InnListener lis,
               dropArticle (peerName,article) ;
             }
           else
-	    syslog (LOG_NOTICE,DYNAMIC_PEER,peerName) ;
+	    {
+	      d_printf (1,"Giving article to peer: %s\n", peerName) ;
+	      hostSendArticle (newHostObj,artTakeRef (article)) ;
+	    }
         }
       else
         {
