@@ -4,7 +4,7 @@
  * Start Date:  Mon, 15 Jan 1996 17:31:58 +1100
  * Project:     INN -- innfeed
  * File:        main.c
- * RCSId:       $Id: main.c,v 1.16 1998/06/05 09:08:07 kondou Exp $
+ * RCSId:       $Id: main.c,v 1.18.2.1 1998/11/11 22:56:56 kondou Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -29,7 +29,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: main.c,v 1.16 1998/06/05 09:08:07 kondou Exp $" ;
+static const char *rcsid = "$Id: main.c,v 1.18.2.1 1998/11/11 22:56:56 kondou Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -174,7 +174,7 @@ int main (int argc, char **argv)
   gPrintInfo = gprintinfo ;
 
   if (ReadInnConf() < 0) {
-      openlog (program,(int)(L_OPENLOG_FLAGS|LOG_PID),LOG_NEWS) ;
+      openlog (program,(int)(L_OPENLOG_FLAGS|LOG_PID),LOG_INN_PROG) ;
       syslog(LOG_ERR, "cant read inn.conf\n");
       exit(1);
   }
@@ -328,12 +328,12 @@ int main (int argc, char **argv)
 
   if ( !checkConfig ) 
     {
-      openlog (program,(int)(L_OPENLOG_FLAGS|LOG_PID),LOG_NEWS) ;
+      openlog (program,(int)(L_OPENLOG_FLAGS|LOG_PID),LOG_INN_PROG) ;
       syslog (LOG_NOTICE,STARTING_PROGRAM,versionInfo,dateString) ;
     }
 
   val = TRUE;
-  if (!SMsetup(SM_RDWR, (void *)&val) || !SMsetup(SM_PREOPEN, (void *)&val)) {
+  if (!SMsetup(SM_PREOPEN, (void *)&val)) {
       syslog(LOG_ERR, "cant setup the storage subsystem\n");
       exit(1);
   }
@@ -486,6 +486,7 @@ int main (int argc, char **argv)
   sleep (initialSleep) ;
 
 
+#if NOFILE_LIMIT > 0
   /* now lower maximum open file limit to match what select(2) can handle. */
   if (getrlimit(RLIMIT_NOFILE,&rl) != 0)
     syslog (LOG_ERR,GETRLIM_FAILED) ;
@@ -504,7 +505,7 @@ int main (int argc, char **argv)
             syslog (LOG_ERR,SETRLIM_FAILED,(long)fd_max);
         }
     }
-  
+#endif	/* NOFILE_LIMIT > 0 */
       
   
   configHosts (talkToSelf) ;
