@@ -4,7 +4,7 @@
  * Start Date:  Wed Dec 27 17:10:18 1995
  * Project:     INN (innfeed)
  * File:        misc.c
- * RCSId:       $Id: misc.c,v 1.6 1998/06/03 07:23:03 kondou Exp $
+ * RCSId:       $Id: misc.c,v 1.7 1998/06/11 23:00:19 kondou Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -29,7 +29,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: misc.c,v 1.6 1998/06/03 07:23:03 kondou Exp $" ;
+static const char *rcsid = "$Id: misc.c,v 1.7 1998/06/11 23:00:19 kondou Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -220,6 +220,10 @@ static const char * const pvt_h_errlist[] = {
 
 static int pvt_h_nerr = (sizeof pvt_h_errlist / sizeof pvt_h_errlist[0]);
 
+#if defined(hpux) || defined(__hpux)
+extern int h_errno;
+#endif
+
 /* return a friendly string for the current value of h_errno. Pinched from
    Stevens */
 const char *host_err_str (void)
