@@ -4,7 +4,7 @@
  * Start Date:  Thu, 01 Feb 1996 22:17:51 +1100
  * Project:     INN -- innfeed
  * File:        sysconfig.h
- * RCSId:       $Id: sysconfig.h,v 1.13 1998/07/06 07:23:42 kondou Exp $
+ * RCSId:       $Id: sysconfig.h,v 1.15.2.3 1999/01/13 07:03:21 kondou Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -45,13 +45,29 @@
  **                      INNFEED PRIVATE SECTION                          **
  ***************************************************************************/
 
+#if defined(sinix)
+/* to avoid duplicate definition when using system derived yacc */
+/* this may be ugly, but do you have another suggestion ? */
+#define yy_yyv _yy_yyv
+#define yyval _yyval
+#define yylval _yylval
+#define yys _yys
+#define yyv _yyv
+#define yyexca _yyexca
+#define yyact _yyact
+#define yypact _yypact
+#define yypgo _yypgo
+#define yyr1 _yyr1
+#define yyr2 _yyr2
+#define yychk _yychk
+#define yydef _yydef
+#endif
 /*
 ** BSD/OS
 */
 
 #if defined (__bsdi__)
 #define MAX_WRITEV_VEC 1024
-#define HAVE_MMAP
 #endif
 
 /*
@@ -69,7 +85,6 @@ extern int h_errno ;
 
 #if defined (__FreeBSD__)
 #define MAX_WRITEV_VEC 1024
-#define HAVE_MMAP
 #endif
 
 /*
@@ -79,7 +94,6 @@ extern int h_errno ;
 
 #if defined (__NetBSD__)
 #define MAX_WRITEV_VEC 1024
-#define HAVE_MMAP
 #endif
 
 
@@ -93,7 +107,6 @@ extern int h_errno ;
    number to use. Lower than that, and you should use 1. */
 #define MAX_WRITEV_VEC 1
 #undef DO_NEED_SYS_SELECT 
-#define HAVE_MMAP 1
 #define USE_SIGACTION
 #endif
 
@@ -131,9 +144,24 @@ extern int h_errno ;
 #define GETSOCKOPT_ARG  char *
 #define MAX_WRITEV_VEC  16
 #define DO_NEED_STREAM 1
-#define HAVE_MMAP
 #define MAX_STDIO_FD 256
 
+/* to avoid duplicate definition when using system derived yacc */
+/* this may be ugly, but do you have another suggestion ? */
+#define yy_yyv _yy_yyv
+#define yyval _yyval
+#define yylval _yylval
+#define yys _yys
+#define yyv _yyv
+#define yyexca _yyexca
+#define yyact _yyact
+#define yypact _yypact
+#define yypgo _yypgo
+#define yyr1 _yyr1
+#define yyr2 _yyr2
+#define yychk _yychk
+#define yydef _yydef
+
  /* this may be needed for solaris version < 2.6 */
 /* #define wait3(a,b,c) waitpid(-1,a,b) */
 
@@ -147,9 +175,25 @@ extern int h_errno ;
 #if defined (sun) && ! defined (__SVR4)
 #define MAX_WRITEV_VEC 16
 #define DO_NEED_STRERROR 1
-#define HAVE_MMAP
 #define MAX_STDIO_FD 128
 #define atexit(arg) on_exit (arg,0)
+
+/* to avoid duplicate definition when using system derived yacc */
+/* this may be ugly, but do you have another suggestion ? */
+#define yy_yyv _yy_yyv
+#define yyval _yyval
+#define yylval _yylval
+#define yys _yys
+#define yyv _yyv
+#define yyexca _yyexca
+#define yyact _yyact
+#define yypact _yypact
+#define yypgo _yypgo
+#define yyr1 _yyr1
+#define yyr2 _yyr2
+#define yychk _yychk
+#define yydef _yydef
+
 #endif
 
 
@@ -160,7 +204,6 @@ extern int h_errno ;
 
 #if defined (__sgi)
 #define MAX_WRITEV_VEC 16    /* actually bigger on 5.2, but this on 5.3 and 6.x */
-#define HAVE_MMAP
 #endif
 
 
@@ -173,11 +216,19 @@ extern int h_errno ;
 #define MAX_WRITEV_VEC 16
 #define DO_NEED_STREAM 1
 #define NO_SBRK 1
-#if ! defined(__GNUC__)
 #define yy_yyv _yy_yyv
 #define yyval _yyval
 #define yylval _yylval
-#endif
+#define yys _yys
+#define yyv _yyv
+#define yyexca _yyexca
+#define yyact _yyact
+#define yypact _yypact
+#define yypgo _yypgo
+#define yyr1 _yyr1
+#define yyr2 _yyr2
+#define yychk _yychk
+#define yydef _yydef
 #endif
 
 
