@@ -5,16 +5,16 @@
 #include <stdio.h>
 #include <sys/types.h>
 #include "configdata.h"
+#include "clibrary.h"
 #include "nntp.h"
 #include "paths.h"
 #include "libinn.h"
-#include "clibrary.h"
 #include "myserver.h"
 
 
 FILE	*ser_rd_fp = NULL;
 FILE	*ser_wr_fp = NULL;
-char	ser_line[NNTP_STRLEN];
+char	ser_line[NNTP_STRLEN + 2];
 
 
 /*
@@ -22,16 +22,11 @@ char	ser_line[NNTP_STRLEN];
 **  our own configuration stuff.  Return pointer to static data.
 */
 /* ARGSUSED0 */
-char *
-getserverbyfile(file)
-    char	*file;
+char *getserverbyfile(char *file)
 {
     static char	buff[256];
-    char	*p;
 
-    if ((p = GetConfigValue(_CONF_SERVER)) == NULL)
-	return NULL;
-    (void)strcpy(buff, p);
+    (void)strcpy(buff, innconf->server);
     return buff;
 }
 
@@ -40,13 +35,11 @@ getserverbyfile(file)
 **  Get a connection to the remote news server.  Return server's reply
 **  code or -1 on error.
 */
-int
-server_init(host)
-    char	*host;
+int server_init(char *host, int port)
 {
     char	line2[NNTP_STRLEN];
 
-    if (NNTPconnect(host, &ser_rd_fp, &ser_wr_fp, ser_line) < 0) {
+    if (NNTPconnect(host, port, &ser_rd_fp, &ser_wr_fp, ser_line) < 0) {
 	if (ser_line[0] == '\0')
 	    /* I/O problem. */
 	    return -1;
@@ -57,7 +50,7 @@ server_init(host)
 
     /* Send the INN command; if understood, use that reply. */
     put_server("mode reader");
-    if (get_server(line2, sizeof line2) < 0)
+    if (get_server(line2, (int)sizeof line2) < 0)
 	return -1;
     if (atoi(line2) != NNTP_BAD_COMMAND_VAL)
 	(void)strcpy(ser_line, line2);
@@ -75,15 +68,27 @@ server_init(host)
 **  Print a message based on the the server's initial response.
 **  Return -1 if server wants us to go away.
 */
-int
-handle_server_response(response, host)
-    int		response;
-    char	*host;
+int handle_server_response(int response, char *host)
 {
+    char	*p;
+
     switch (response) {
     default:
 	(void)printf("Unknown response code %d from %s.\n", response, host);
 	return -1;
+     case NNTP_GOODBYE_VAL:
+	if (atoi(ser_line) == response) {
+	    p = &ser_line[strlen(ser_line) - 1];
+	    if (*p == '\n' && *--p == '\r')
+		*p = '\0';
+	    if (p > &ser_line[3]) {
+		(void)printf("News server %s unavailable: %s\n", host,
+			&ser_line[4]);
+		return -1;
+	    }
+	}
+	(void)printf("News server %s unavailable, try later.\n", host);
+	return -1;
     case NNTP_ACCESS_VAL:
 	(void)printf(CANTUSE, host);
 	return -1;
@@ -113,12 +118,9 @@ put_server(buff)
 **  Get a line of text from the server, strip trailing \r\n.
 **  Return -1 on error.
 */
-int
-get_server(buff, buffsize)
-    register char	*buff;
-    int			buffsize;
+int get_server(char *buff, int buffsize)
 {
-    register char	*p;
+    char	        *p;
 
     if (fgets(buff, buffsize, ser_rd_fp) == NULL)
 	return -1;
@@ -142,7 +144,7 @@ close_server()
 	(void)fclose(ser_wr_fp);
 	ser_wr_fp = NULL;
 
-	(void)get_server(buff, sizeof buff);
+	(void)get_server(buff, (int)sizeof buff);
 	(void)fclose(ser_rd_fp);
 	ser_rd_fp = NULL;
     }
