@@ -1,12 +1,11 @@
-/*  $Revision: 1.4 $
+/*  $Revision: 1.2 $
 **
 */
-#include "configdata.h"
 #include <stdio.h>
 #include <sys/types.h>
-#include <errno.h>
+#include "configdata.h"
 #include "clibrary.h"
-
+#include <errno.h>
 
 
 #if	defined(CLX_IOCTL)
@@ -17,14 +16,12 @@
 **  Mark a file close-on-exec so that it doesn't get shared with our
 **  children.  Ignore any error codes.
 */
-void
-CloseOnExec(fd)
-    int		fd;
+void CloseOnExec(int fd, int flag)
 {
     int		oerrno;
 
     oerrno = errno;
-    (void)ioctl(fd, FIOCLEX, (char *)NULL);
+    (void)ioctl(fd, (unsigned long) (flag ? FIOCLEX : FIONCLEX), (char *)NULL);
     errno = oerrno;
 }
 #endif	/* defined(CLX_IOCTL) */
@@ -39,14 +36,12 @@ CloseOnExec(fd)
 **  Mark a file close-on-exec so that it doesn't get shared with our
 **  children.  Ignore any error codes.
 */
-void
-CloseOnExec(fd)
-    int		fd;
+void CloseOnExec(int fd, int flag)
 {
     int		oerrno;
 
     oerrno = errno;
-    (void)fcntl(fd, F_SETFD, 1);
+    (void)fcntl(fd, F_SETFD, flag ? 1 : 0);
     errno = oerrno;
 }
 #endif	/* defined(CLX_FCNTL) */
