@@ -1,11 +1,11 @@
-/*  $Revision: 1.11 $
+/*  $Revision: 1.5 $
 **
 */
 #include <stdio.h>
 #include <sys/types.h>
 #include "configdata.h"
-#include "clibrary.h"
 #include <netdb.h>
+#include "clibrary.h"
 #include "paths.h"
 #include "libinn.h"
 
@@ -13,8 +13,7 @@
 /*
 **  Get the fully-qualified domain name for this host.
 */
-char *
-GetFQDN()
+char *GetFQDN(void)
 {
     static char		buff[SMBUF];
     struct hostent	*hp;
@@ -74,7 +73,7 @@ GetFQDN()
 	    }
 
     /* Give up:  Get the domain config param and append it. */
-    if ((p = GetFileConfigValue(_CONF_DOMAIN)) == NULL || *p == '\0')
+    if ((p = innconf->domain) == NULL || *p == '\0')
 	return NULL;
     if (strlen(buff) + 1 + strlen(p) > sizeof buff - 1)
 	/* Doesn't fit. */
