@@ -66,7 +66,7 @@ HASH HashMessageID(const char *MessageID) {
     len = strlen(MessageID);
     if (newlen <= len) {
 	if (new)
-	    new = RENEW(new, char, len + 1);
+	    RENEW(new, char, len + 1);
 	else
 	    new = NEW(char, len + 1);
 	newlen = len + 1;
@@ -118,7 +118,7 @@ char *HashToText(const HASH hash) {
 /*
 ** Converts a hex digit and converts it to a int
 */
-STATIC int hextodec(const char c) {
+STATIC int hextodec(const int c) {
     return isdigit(c) ? (c - '0') : ((c - 'A') + 10);
 }
 
