@@ -3,13 +3,13 @@
  * Author:      Christophe Wolfhugel <wolf@pasteur.fr>
  *		(although he wouldn't recognise it anymore so don't blame him)
  * File:        perl.c
- * RCSId:       $Id: perl.c,v 1.7.2.1 1999/06/25 03:16:00 kondou Exp $
+ * RCSId:       $Id: perl.c,v 1.7.2.3 1999/09/25 22:42:25 rra Exp $
  * Description: Perl hooks for libinn.a
  * 
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: perl.c,v 1.7.2.1 1999/06/25 03:16:00 kondou Exp $" ;
+static const char *rcsid = "$Id: perl.c,v 1.7.2.3 1999/09/25 22:42:25 rra Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -34,12 +34,7 @@ typedef enum { false = 0, true = 1 } bool;
 #include <EXTERN.h>
 #include <perl.h>
 #include <XSUB.h>
-
-/* Perl 5.004 didn't define ERRSV and PL_na was called na. */
-#ifndef ERRSV
-# define ERRSV GvSV(errgv)
-# define PL_na na
-#endif
+#include "ppport.h"
 
 extern void xs_init    _((void));
 extern void boot_DynaLoader _((CV* cv));
