@@ -1,14 +1,18 @@
-/*  $Revision: 1.4 $
+/*  $Revision: 1.5 $
 **
 */
 #include <stdio.h>
 #include <sys/types.h>
 #include "configdata.h"
 #include "clibrary.h"
-#include <sys/wait.h>
+#ifdef HAVE_WAIT_H
+# include <wait.h>
+#else
+# include <sys/wait.h>
+#endif
 
 
-#if	defined(DO_USE_UNION_WAIT)
+#if	defined(HAVE_UNION_WAIT)
 typedef union wait	WAITER;
 #if	defined(WEXITSTATUS)
 #define WAITVAL(x)	(WEXITSTATUS(x))
@@ -18,22 +22,18 @@ typedef union wait	WAITER;
 #else
 typedef int		WAITER;
 #define WAITVAL(x)	(((x) >> 8) & 0xFF)
-#endif	/* defined(DO_USE_UNION_WAIT) */
+#endif	/* defined(HAVE_UNION_WAIT) */
 
-PID_T
-waitnb(statusp)
-    int		*statusp;
+PID_T waitnb(int *statusp)
 {
     WAITER	w;
     PID_T	pid;
 
-#if	defined(DO_HAVE_WAITPID)
+#if defined(HAVE_WAITPID)
     pid = waitpid(-1, &w, WNOHANG);
-#endif	/* defined(DO_HAVE_WAITPID) */
-
-#if	defined(DONT_HAVE_WAITPID)
+#else
     pid = wait3(&w, WNOHANG, (struct rusage *)NULL);
-#endif	/* defined(DONT_HAVE_WAITPID) */
+#endif	
 
     if (pid > 0)
 	*statusp = WAITVAL(w);
