@@ -1,4 +1,4 @@
-/*  $Revision: 1.24 $
+/*  $Revision: 1.26 $
 **
 **  Net News Reading Protocol server.
 */
@@ -87,9 +87,9 @@ typedef enum _READTYPE {
 typedef struct _ARTLIST {
     ARTNUM              ArtNum;
     char                (*Index)[OVERINDEXPACKSIZE];
-    TOKEN		Token; /* for overview */
-    OFFSET_T		Offset;
-    BOOL		Tokenretrieved;
+    TOKEN		Token;            /* for overview */
+    OFFSET_T		Offset;           /* Offset into history file */
+    BOOL		Tokenretrieved; 
 } ARTLIST;
 
 
@@ -127,7 +127,6 @@ EXTERN ARTLIST	*ARTnumbers;
 EXTERN FILE	*locallog;
 EXTERN int	ARTindex;
 EXTERN int	ARTsize;
-extern int	PERMdefault;
 EXTERN long	ARTcount;
 EXTERN long	ARTget;
 EXTERN long	ARTgettime;
@@ -193,4 +192,8 @@ ARTNUM GPLOW(GROUPENTRY *gp);
 ARTNUM GPHIGH(GROUPENTRY *gp);
 char GPFLAG(GROUPENTRY *gp);
 char *GPALIAS(GROUPENTRY *gp); 
+char *HandleHeaders(char *article);
+int perlConnect(char *ClientHost, char *ClientIP, char *accesslist);
+int perlAuthenticate(char *ClientHost, char *ClientIP, char *user, char *passwd, char *accesslist);
+
 
