@@ -58,7 +58,7 @@ sub collect
   if ($prog eq "inn")
   { 
     # accepted article
-    if ($res =~ m/[\+cj]/o)
+    if ($res =~ m/[\+j]/o)
     {
       $hour =~ s/:.*$//o;
       $inn_flow{"$day $hour"}++;
@@ -220,6 +220,7 @@ sub collect
     {
       my $command = $1;
       my $cmd = $ctlinnd{$command};
+      $cmd = $command unless $cmd;
       return 1 if ($cmd eq 'flush'); # to avoid a double count
       $innd_control{"$cmd"}++;
       return 1;
@@ -653,18 +654,52 @@ sub collect
       my ($server, $seconds, $offered, $accepted, $refused, $rejected,
 	  $missing, $spooled) = ($1, $2, $3, $4, $5, $6, $7, $8);
       $server =~ tr/A-Z/a-z/ unless ($CASE_SENSITIVE);
+      $tt_innfeed_seconds{$server} += $seconds;
+      $tt_innfeed_offered{$server} += $offered;
+      $tt_innfeed_accepted{$server} += $accepted;
+      $tt_innfeed_refused{$server} += $refused;
+      $tt_innfeed_missing{$server} += $missing;
+      $tt_innfeed_spooled{$server} += $spooled;
+      $tt_innfeed_rejected{$server} += $rejected;
+      $t_innfeed_seconds{$server} = 0;
+      $t_innfeed_offered{$server} = 0;
+      $t_innfeed_accepted{$server} = 0;
+      $t_innfeed_refused{$server} = 0;
+      $t_innfeed_missing{$server} = 0;
+      $t_innfeed_spooled{$server} = 0;
+      $t_innfeed_rejected{$server} = 0;
+      return 1;
+    }
+    # global (real)
+    if ($left =~ /(\S+) global seconds (\d+) offered (\d+) accepted (\d+) refused (\d+) rejected (\d+) missing (\d+)/o)
+    {
+      my ($server, $seconds, $offered, $accepted, $refused, $rejected,
+	  $missing) = ($1, $2, $3, $4, $5, $6, $7);
+      if ($server eq "ME") {
+        return 1;
+      }
+      $server =~ tr/A-Z/a-z/ unless ($CASE_SENSITIVE);
       $innfeed_seconds{$server} += $seconds;
       $innfeed_offered{$server} += $offered;
       $innfeed_accepted{$server} += $accepted;
       $innfeed_refused{$server} += $refused;
       $innfeed_rejected{$server} += $rejected;
       $innfeed_missing{$server} += $missing;
-      $innfeed_spooled{$server} += $spooled;
+      $innfeed_spooled{$server} += $spooled + $t_innfeed_spooled{$server};
       $t_innfeed_seconds{$server} = 0;
       $t_innfeed_offered{$server} = 0;
       $t_innfeed_accepted{$server} = 0;
       $t_innfeed_refused{$server} = 0;
+      $t_innfeed_missing{$server} = 0;
+      $t_innfeed_spooled{$server} = 0;
       $t_innfeed_rejected{$server} = 0;
+      $tt_innfeed_seconds{$server} = 0;
+      $tt_innfeed_offered{$server} = 0;
+      $tt_innfeed_accepted{$server} = 0;
+      $tt_innfeed_refused{$server} = 0;
+      $tt_innfeed_missing{$server} = 0;
+      $tt_innfeed_spooled{$server} = 0;
+      $tt_innfeed_rejected{$server} = 0;
       return 1;
     }
     # final (only seconds & spooled)
@@ -1600,7 +1635,7 @@ sub adjust
   ## from innreport although the data in the logs is correctly
   ## parsed and understood).
   
-  if (%t_innfeed_seconds && !(%innfeed_seconds))
+  if (%t_innfeed_seconds)
   {
     # do it only of there are no data recorded but temporary
     my $server;
@@ -1611,6 +1646,23 @@ sub adjust
       $innfeed_accepted{$server} += $t_innfeed_accepted{$server}; 
       $innfeed_refused{$server} += $t_innfeed_refused{$server};
       $innfeed_rejected{$server} += $t_innfeed_rejected{$server};
+      $innfeed_missing{$server} += $t_innfeed_missing{$server};
+      $innfeed_spooled{$server} += $t_innfeed_spooled{$server};
+    }
+  }
+  if (%tt_innfeed_seconds)
+  {
+    # do it only of there are no data recorded but temporary
+    my $server;
+    foreach $server (sort keys (%tt_innfeed_seconds))
+    {
+      $innfeed_seconds{$server} += $tt_innfeed_seconds{$server};
+      $innfeed_offered{$server} += $tt_innfeed_offered{$server};
+      $innfeed_accepted{$server} += $tt_innfeed_accepted{$server}; 
+      $innfeed_refused{$server} += $tt_innfeed_refused{$server};
+      $innfeed_rejected{$server} += $tt_innfeed_rejected{$server};
+      $innfeed_missing{$server} += $tt_innfeed_missing{$server};
+      $innfeed_spooled{$server} += $tt_innfeed_spooled{$server};
     }
   }
   
