@@ -1,5 +1,5 @@
 #! /bin/sh
-##  $Revision: 1.5 $
+##  $Revision: 1.1.1.1.4.1 $
 ##  Run subst over a list of files.  Get files in and out of source control
 ##  if present.
 
@@ -52,7 +52,7 @@ LISTOFFILES=../${BASEDIRNAME}/files.$$
 for I in ${PLAIN} ${CONTROLLED} ; do
     echo ../${BASEDIRNAME}/${I}
 done >${LISTOFFILES}
-( cd ../config; make quiet FILE=${LISTOFFILES} )
+( cd ../config; ${MAKE:=make} quiet FILE=${LISTOFFILES} )
 rm -f ${LISTOFFILES}
 
 # check which files we really changed
